/*--------------------------------------------------------------------------
 *  Copyright 2008 utgenome.org
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *--------------------------------------------------------------------------*/
//--------------------------------------
// utgb-shell Project
//
// Import.java
// Since: Jan 20, 2009
//
// $URL: http://svn.utgenome.org/utgb/trunk/utgb/utgb-shell/src/main/java/org/utgenome/shell/Import.java $ 
// $Author: leo $
//--------------------------------------
package org.utgenome.shell;

import java.io.File;
import java.io.FileReader;
import java.sql.SQLException;

import org.utgenome.shell.db.bed.BEDDatabaseGenerator;
import org.utgenome.shell.db.read.GenomeReadFormatDBBuilder;
import org.xerial.util.bean.BeanUtil;
import org.xerial.util.log.Logger;
import org.xerial.util.opt.Argument;
import org.xerial.util.opt.Option;
import org.xerial.util.opt.OptionParser;

/**
 * import command
 * 
 * @author leo
 * 
 */
// @Usage(command = "> utgb import", description = "import command")
public class Import extends UTGBShellSubCommandBase {

	private static Logger _logger = Logger.getLogger(Import.class);
	private OptionParser parser = null;

	private enum FileType {
		AUTO, READ, BED
	}

	@Option(symbol = "t", longName = "type", description = "specify the input file type: (AUTO, READ, BED)")
	private FileType fileType = FileType.AUTO;

	@Argument(index = 0, required = true)
	private String inputFilePath = null;

	@Option(symbol = "o", longName = "output", varName = "DB FILE NAME", description = "output SQLite DB file name")
	private String outputFileName;

	private OptionParser getOptionParser() {
		if (parser == null)
			parser = new OptionParser(this);

		return parser;
	}

	@Override
	public void execute(String[] args) throws UTGBShellException {

		try {
			getOptionParser().parse(args);

			_logger.info("input file: " + inputFilePath);
			_logger.info("file type: " + fileType);

			File input = new File(inputFilePath);
			if (!input.exists())
				throw new UTGBShellException("file not found: " + inputFilePath);

			if (outputFileName == null) {
				// new File("db").mkdirs();

				outputFileName = String.format("%s.sqlite", inputFilePath);
				int count = 1;
				while (new File(outputFileName).exists()) {
					outputFileName = String.format("%s.sqlite.%d", inputFilePath, count++);
				}
			}

			_logger.info("output file: " + outputFileName);

			switch (fileType) {
			case READ: {
				GenomeReadFormatDBBuilder reader = new GenomeReadFormatDBBuilder(outputFileName);
				BeanUtil.populateBeanWithSilk(reader, input.toURL());

				_logger.info("commit");
				reader.commit();
				break;
			}
			case BED: {
				BEDDatabaseGenerator.toSQLiteDB(new FileReader(input), outputFileName);
				break;
			}
			case AUTO:
			default: {
				_logger.warn("file type (-t) must be given");
				break;
			}
			}

		}
		catch (SQLException e) {
			e.printStackTrace();
		}
		catch (Exception e) {
			_logger.error(e);
		}

	}

	@Override
	public String name() {
		return "import";
	}

	public String getDetailedDescription() {
		return loadUsage("help-import.txt");
	}

	public String getOneLinerDescription() {
		return "import a file and create a new database";
	}

	public String getOptionList() {
		return getOptionParser().getUsage();
	}
}
